package com.zg.project.information.service;

import java.util.List;
import com.zg.project.information.domain.Mtd;

/**
 * 物料字典Service接口
 * 
 * @author zg
 * @date 2025-07-31
 */
public interface IMtdService 
{
    /**
     * 查询物料字典
     * 
     * @param Id 物料字典主键
     * @return 物料字典
     */
    public Mtd selectMtdById(Long Id);

    /**
     * 查询物料字典列表
     * 
     * @param mtd 物料字典
     * @return 物料字典集合
     */
    public List<Mtd> selectMtdList(Mtd mtd);

    /**
     * 新增物料字典
     * 
     * @param mtd 物料字典
     * @return 结果
     */
    public int insertMtd(Mtd mtd);

    /**
     * 修改物料字典
     * 
     * @param mtd 物料字典
     * @return 结果
     */
    public int updateMtd(Mtd mtd);

    /**
     * 批量删除物料字典
     * 
     * @param Ids 需要删除的物料字典主键集合
     * @return 结果
     */
    public int deleteMtdByIds(Long[] Ids);

    /**
     * 删除物料字典信息
     * 
     * @param Id 物料字典主键
     * @return 结果
     */
    public int deleteMtdById(Long Id);
}
